function [y, priblizki]=iteracija(f,x0,delta,maxsteps)

% y=ITERACIJA(f,x0,delta,maxsteps) izvaja iteracijo za funkcijo f z zacetnim 
% priblizkom x0.  Funkcija f morata biti podana 
% v obliki inline funkcije ali anonimne funkcije (npr. f=inline('x^2-2'), f = @(x) x^2 - 2).
% Ce podajamo funkcijo, ki jr napisana v posebnih datoteki, klic izgleda
% takole: sekantna(@f,x0,x1,delta,maxsteps) ali takole  sekantna('f',x0,x1,delta,maxsteps).
% Iteracija se konca, ko se zadnja priblizka relativno
% razlikujeta za manj kot delta ali ko prekoracimo maksimalno stevilo korakov maxsteps.
% Ce zadnjih dveh argumentov ne podamo, je privzeta vrednost za delta osnovna 
% zaokrozitvena napaka eps, za maxsteps pa 50. Funkcija f je lahko tudi
% vektorska, x0 pa mora biti potem vektor ustrezne dimenzije.
 
% Bor Plestenjak 2004, posodobil Andrej Muhic 2013

% ce ne podamo tretjega argumenta z natancnostjo, privzamemo osnovno zaokrozitvno napako
if nargin<3, delta=eps; end
% ce ne podamo cetrtega argumenta z maksimalnim stevilom iteracij, vzamemo 50
if nargin<4, maxsteps=50; end

if nargout == 2
    priblizki = zeros(1, maxsteps);
end

xn=x0;
x0=Inf; 
korak=0;

while (norm(xn-x0,'inf')>delta*norm(xn,'inf')) && (korak<maxsteps)
   korak=korak+1;           						 
   if nargout == 2
       priblizki(korak) = x0;
   end
   x0=xn;
   xn=feval(f, x0); 
   if nargout == 2
       disp(sprintf('%3d:  %s %0.1e',korak,sprintf('%15.15f  ',xn),norm(xn-x0,'inf')/norm(x0,'inf')));  % nepomembno, izpisemo trenutni priblizek
   end
end
if nargout == 2
    priblizki = priblizki(1:korak);
end
y=xn;