function y=laguerre(p,x0,verzija,delta,maxsteps)

% y=LAGUERRE(p,x0,verzija,delta,maxsteps) dela Laguerrovo iteracijo za polinom p 
% z zacetnim priblizkom x0. Verzija je lahko 1 (stabilna), 2 (fiksno +), 3 (fiskno -),
% ce jo ne podamo je privzeto 1.
% 
% iteracija se konca, ko je dosezena relativna natancnost delta ali ko je 
% presezeno stevilo iteracij maxsteps. Ce vrednosti ne podamo v klicu metode
% so privzete vrednosti delta=1e-12 in maxsteps=50

% BP 2002/2003

if nargin<3, verzija=1; end
if nargin<4, delta=1e-12; end
if nargin<5, maxsteps=50; end

p1=polyder(p);
p2=polyder(p1);
n=length(p)-1;

xn=x0;
x0=Inf;

korak=0;                    						 
while (abs(xn-x0)>(delta*abs(xn))) & (korak<maxsteps)
   
   x0=xn;
   f=polyval(p,x0);
   f1=polyval(p1,x0);
   f2=polyval(p2,x0);
   
   if verzija==1, predznak=sign(f1);   if predznak==0, predznak=1; end, end
   if verzija==2, predznak=1; end
   if verzija==3, predznak=-1; end
   
   xn=x0-n*f/(f1+predznak*sqrt((n-1)*((n-1)*f1^2-n*f*f2)));
   
   korak=korak+1;           						 
   if (imag(xn)~=0)
      disp(sprintf('%3d: %15.15f %+15.15fi',[korak,real(xn),imag(xn)]));  
   else
      disp(sprintf('%3d: %15.15f',[korak,xn]));  
   end
   pause(0.3)
end   

y=xn;