function [y, priblizki]=sekantna(f,x0,x1,delta,maxsteps)

% y=SEKANTNA(f,x0,x1,delta,maxsteps) dela sekantno metodo za funkcijo f 
% z zacetnima priblizkoma x0 in x1. Funkcija f morata biti podana 
% v obliki inline funkcije ali anonimne funkcije (npr. f=inline('x^2-2'), f = @(x) x^2 - 2).
% Ce podajamo funkcijo, ki jr napisana v posebnih datoteki, klic izgleda
% takole: sekantna(@f,x0,x1,delta,maxsteps) ali takole  sekantna('f',x0,x1,delta,maxsteps).  Iteracija se konca, ko se zadnja priblizka relativno
% razlikujeta za manj kot delta ali ko prekoracimo maksimalno stevilo korakov maxsteps.
% Ce zadnjih dveh argumentov ne podamo, je privzeta vrednost za delta osnovna 
% zaokrozitvena napaka eps, za maxsteps pa 50.

% Bor Plestenjak 2004,  posodobitev Andrej Muhic 2013
% Funkcija zdaj na zahtevo vrne tudi priblizke, ce zahtevamo dva izhodna
% argumenta, takrat nam priblizke po korakih tudi izpise

if nargin<4, delta=eps; end
if nargin<5, maxsteps=50; end

if nargout == 2
    priblizki = zeros(1, maxsteps);
end

xn=x1;
x1=x0;
korak=0;

%Ce uporabnik vnese priblizka preblizu, metode ne smemo koncati po enem
%koraku
x0=x1;
x1=xn;

if nargout == 2
    priblizki(korak+1) = xn;
end
xn=x1-(x1-x0)/(feval(f, x1)-feval(f, x0))*feval(f, x1);
korak = korak + 1;
while (abs(xn-x1)>delta*abs(xn)) && (korak<maxsteps)
    x0=x1;
    x1=xn;
    if nargout == 2
        priblizki(korak) = xn; 
    end
    fx1 = feval(f, x1);
    fx0 = feval(f, x0);
    deltaf = fx1 - fx0; %deltaf = f' * (x1-x0)
    odvod_priblizek = deltaf/(x1-x0);
    xn=x1-fx1/odvod_priblizek;
    korak=korak+1;
    if nargout == 2
        if (imag(xn)~=0)
            disp(sprintf('%3d: %15.15f %+15.15fi',[korak,real(xn),imag(xn)]));
        else
            disp(sprintf('%3d: %15.15f',[korak,xn]));
        end
    end
end   
%Znebimo se odvecnih priblizkov, ce metoda skonvergira prej kot v maxsteps korakih
if nargout == 2
    priblizki = priblizki(1:korak);
end
y=xn;