function [y, priblizki] = tangentna(f,fprime,x0,delta,maxsteps)

% y=TANGENTNA(f,fprime,x0,delta,maxsteps) dela tangentno metodo za funkcijo f 
% in odvod fprime z zacetnim priblizkom x0. Funkciji f in fprime morata biti podani 
% v obliki inline funkcij ali anonimne funkcije (npr. f=inline('x^2-2'), f = @(x) x^2 - 2).
% Ce podajamo funkciji, ki sta napisani v posebnih datotekah, klic izgleda
% takole tangentna(@f,@fprime,x0,delta,maxsteps) ali takole  tangentna('f','fprime',x0,delta,maxsteps) 
% Iteracija se konca, ko se zadnja 
% priblizka relativno razlikujeta za manj kot delta ali ko prekoracimo maksimalno 
% stevilo korakov maxsteps. Ce zadnjih dveh argumentov ne podamo, je privzeta vrednost 
% za delta osnovna zaokrozitvena napaka eps, za maxsteps pa 50.
% Vrnemo koncni priblizek za niclo y in na zahtevo tudi vse priblizke v spremenljivki priblizki; 

% Bor Plestenjak 2004, posodobitev Andrej Muhic 2013
% Funkcija zdaj na zahtevo vrne tudi priblizke, ce zahtevamo dva izhodna
% argumenta, takrat nam priblizke po korakih tudi izpise

if nargin<4, delta=eps; end
if nargin<5, maxsteps=50; end

if nargout == 2
    priblizki = zeros(1, maxsteps);
end

xn=x0;
x0=Inf;
korak=0;                    						 
while (abs(xn-x0)>delta*abs(xn)) && (korak<maxsteps)
    korak=korak+1; 
    x0=xn;
    if nargout == 2
        priblizki(korak) = x0; 
    end
    xn=x0-feval(f, x0)/feval(fprime, x0);
    if nargout == 2
        if (imag(xn)~=0)
            disp(sprintf('%3d: %15.15f %+15.15fi',[korak,real(xn),imag(xn)]));
        else
            disp(sprintf('%3d: %15.15f',[korak,xn]));
        end
    end
end   
%Znebimo se odvecnih priblizkov, ce metoda skonvergira prej kot v maxsteps korakih
if nargout == 2
    priblizki = priblizki(1:korak);
end
y=xn;